import { useEffect, useRef, useState } from "react";

export default function useComponentVisible(initialIsVisible: boolean) {
    const [isCompVisible, setIsCompVisible] =
        useState<boolean>(initialIsVisible);

    const ref = useRef<HTMLDivElement>(null);
    const handleClickOutsideComp = (event: Event) => {
        if (ref.current && !ref.current.contains(event.target as Node)) {
            setIsCompVisible(false);
        }
    };

    useEffect(() => {
        document.addEventListener("click", handleClickOutsideComp, true);
        return () => {
            document.removeEventListener("click", handleClickOutsideComp, true);
        };
    });

    const openComp = () => setIsCompVisible(true);

    return { ref, isCompVisible, openComp };
}
